HiPSCat - Hierarchical Progressive Survey Catalog
========================================================================================

.. toctree::
   :maxdepth: 1
   :caption: Overview

   guide/directory_scheme
   Notebooks <notebooks>

.. toctree::
   :maxdepth: 1
   :caption: Developers

   guide/contributing
   Pixel math <guide/pixel_math>
   API Reference <autoapi/index>